@@ -222,7 +222,7 @@ aparams_strtoenc(struct aparams *par, char *istr)
 		return 0;
 
 done:
-       	par->msb = msb;
+	par->msb = msb;
 	par->sig = sig;
 	par->bits = bits;
 	par->bps = bps;
@@ -366,7 +366,8 @@ resamp_do(struct resamp *p, adata_t *in, adata_t *out, int todo)
  * initialize resampler with ibufsz/obufsz factor and "nch" channels
  */
 void
-resamp_init(struct resamp *p, unsigned int iblksz, unsigned int oblksz, int nch)
+resamp_init(struct resamp *p, unsigned int iblksz,
+    unsigned int oblksz, int nch)
 {
 	unsigned int i;
 
@@ -516,7 +517,7 @@ enc_init(struct conv *p, struct aparams *par, int nch)
 		p->bias = (1U << 31) >> p->shift;
 	} else {
 		p->bias = 0;
-	}	
+	}
 	if (!par->le) {
 		p->bfirst = par->bps - 1;
 		p->bnext = -1;
@@ -673,7 +674,8 @@ dec_do_float(struct conv *p, unsigned char *in, unsigned char *out, int todo)
  * convert samples from ulaw/alaw to adata_t
  */
 void
-dec_do_ulaw(struct conv *p, unsigned char *in, unsigned char *out, int todo, int is_alaw)
+dec_do_ulaw(struct conv *p, unsigned char *in,
+    unsigned char *out, int todo, int is_alaw)
 {
 	unsigned int f;
 	unsigned char *idata;
@@ -711,7 +713,7 @@ dec_init(struct conv *p, struct aparams *par, int nch)
 		p->bias = (1U << 31) >> p->shift;
 	} else {
 		p->bias = 0;
-	}	
+	}
 	if (par->le) {
 		p->bfirst = par->bps - 1;
 		p->bnext = -1;
