@@ -35,9 +35,11 @@
 #include "sio_priv.h"
 #include "bsd-compat.h"
 
+#define DEVNAME_PREFIX "hw:"
+
 #ifdef DEBUG
 static snd_output_t *output = NULL;
-#define DALSA(str, err) fprintf(stderr, "%s: %s\n", str, snd_strerror(err)) 
+#define DALSA(str, err) fprintf(stderr, "%s: %s\n", str, snd_strerror(err))
 #else
 #define DALSA(str, err) do {} while (0)
 #endif
@@ -45,6 +47,7 @@ static snd_output_t *output = NULL;
 struct sio_alsa_hdl {
 	struct sio_hdl sio;
 	struct sio_par par;
+	char *devname;
 	snd_pcm_t *opcm;
 	snd_pcm_t *ipcm;
 	unsigned ibpf, obpf;		/* bytes per frame */
@@ -100,9 +103,9 @@ static unsigned int cap_rates[] = {
 };
 static snd_pcm_format_t cap_fmts[] = {
 	/* XXX add s24le3 and s24be3 */
-	SND_PCM_FORMAT_S32_LE,	SND_PCM_FORMAT_S32_BE, 
-	SND_PCM_FORMAT_S24_LE,	SND_PCM_FORMAT_S24_BE, 
-	SND_PCM_FORMAT_S16_LE,	SND_PCM_FORMAT_S16_BE, 
+	SND_PCM_FORMAT_S32_LE,	SND_PCM_FORMAT_S32_BE,
+	SND_PCM_FORMAT_S24_LE,	SND_PCM_FORMAT_S24_BE,
+	SND_PCM_FORMAT_S16_LE,	SND_PCM_FORMAT_S16_BE,
 	SND_PCM_FORMAT_U8
 };
 
@@ -272,17 +275,23 @@ sio_alsa_enctofmt(struct sio_alsa_hdl *hdl, snd_pcm_format_t *rfmt,
 struct sio_hdl *
 _sio_alsa_open(const char *str, unsigned mode, int nbio)
 {
+	const char *p;
 	struct sio_alsa_hdl *hdl;
-	char path[PATH_MAX];
 	struct sio_par par;
+	size_t len;
 	int err;
 
-	switch (*str) {
+	p = _sndio_parsetype(str, "rsnd");
+	if (p == NULL) {
+		DPRINTF("_sio_alsa_open: %s: \"rsnd\" expected\n", str);
+		return NULL;
+	}
+	switch (*p) {
 	case '/':
-		str++;
+		p++;
 		break;
 	default:
-		DPRINTF("_sio_sun_open: %s: '/<devnum>' expected\n", str);
+		DPRINTF("_sio_alsa_open: %s: '/' expected\n", str);
 		return NULL;
 	}
 	hdl = malloc(sizeof(struct sio_alsa_hdl));
@@ -295,10 +304,14 @@ _sio_alsa_open(const char *str, unsigned mode, int nbio)
 	if (err < 0)
 		DALSA("couldn't attach to stderr", err);
 #endif
-
-	snprintf(path, sizeof(path), "hw:%s", str);
+	len = strlen(p);
+	hdl->devname = malloc(len + sizeof(DEVNAME_PREFIX));
+	if (hdl->devname == NULL)
+		goto bad_free_hdl;
+	memcpy(hdl->devname, DEVNAME_PREFIX, sizeof(DEVNAME_PREFIX) - 1);
+	memcpy(hdl->devname + sizeof(DEVNAME_PREFIX) - 1, p, len + 1);
 	if (mode & SIO_PLAY) {
-		err = snd_pcm_open(&hdl->opcm, path,
+		err = snd_pcm_open(&hdl->opcm, hdl->devname,
 		    SND_PCM_STREAM_PLAYBACK, SND_PCM_NONBLOCK);
 		if (err < 0) {
 			DALSA("couldn't open play stream", err);
@@ -306,7 +319,7 @@ _sio_alsa_open(const char *str, unsigned mode, int nbio)
 		}
 	}
 	if (mode & SIO_REC) {
-		err = snd_pcm_open(&hdl->ipcm, path,
+		err = snd_pcm_open(&hdl->ipcm, hdl->devname,
 		    SND_PCM_STREAM_CAPTURE, SND_PCM_NONBLOCK);
 		if (err < 0) {
 			DALSA("couldn't open rec stream", err);
@@ -345,6 +358,8 @@ bad_free_opcm:
 	if (mode & SIO_PLAY)
 		snd_pcm_close(hdl->opcm);
 bad_free:
+	free(hdl->devname);
+bad_free_hdl:
 	free(hdl);
 	return NULL;
 }
@@ -358,6 +373,7 @@ sio_alsa_close(struct sio_hdl *sh)
 		snd_pcm_close(hdl->opcm);
 	if (hdl->sio.mode & SIO_REC)
 		snd_pcm_close(hdl->ipcm);
+	free(hdl->devname);
 	free(hdl);
 }
 
@@ -482,11 +498,11 @@ sio_alsa_xrun(struct sio_alsa_hdl *hdl)
 	 *
 	 * to understand the formula, draw a picture :)
 	 */
-	rbpf = (hdl->sio.mode & SIO_REC) ? 
+	rbpf = (hdl->sio.mode & SIO_REC) ?
 	    hdl->sio.par.bps * hdl->sio.par.rchan : 1;
 	wbpf = (hdl->sio.mode & SIO_PLAY) ?
 	    hdl->sio.par.bps * hdl->sio.par.pchan : 1;
-	rround = hdl->sio.par.round * rbpf; 
+	rround = hdl->sio.par.round * rbpf;
 
 	clk = hdl->sio.cpos % hdl->sio.par.round;
 	rdrop = (clk * rbpf - hdl->sio.rused) % rround;
@@ -521,12 +537,12 @@ sio_alsa_setpar_hw(snd_pcm_t *pcm, snd_pcm_hw_params_t *hwp,
     snd_pcm_uframes_t *round, unsigned int *periods)
 {
 	static snd_pcm_format_t fmts[] = {
-		SND_PCM_FORMAT_S32_LE,	SND_PCM_FORMAT_S32_BE, 
+		SND_PCM_FORMAT_S32_LE,	SND_PCM_FORMAT_S32_BE,
 		SND_PCM_FORMAT_U32_LE,	SND_PCM_FORMAT_U32_BE,
-		SND_PCM_FORMAT_S24_LE,	SND_PCM_FORMAT_S24_BE, 
+		SND_PCM_FORMAT_S24_LE,	SND_PCM_FORMAT_S24_BE,
 		SND_PCM_FORMAT_U24_LE,	SND_PCM_FORMAT_U24_BE,
-		SND_PCM_FORMAT_S16_LE,	SND_PCM_FORMAT_S16_BE, 
-		SND_PCM_FORMAT_U16_LE,	SND_PCM_FORMAT_U16_BE, 
+		SND_PCM_FORMAT_S16_LE,	SND_PCM_FORMAT_S16_BE,
+		SND_PCM_FORMAT_U16_LE,	SND_PCM_FORMAT_U16_BE,
 		SND_PCM_FORMAT_U8,	SND_PCM_FORMAT_S8
 	};
 	int i, err, dir = 0;
@@ -683,7 +699,7 @@ sio_alsa_getcap(struct sio_hdl *sh, struct sio_cap *cap)
 		sio_alsa_fmttopar(hdl, cap_fmts[i],
 		    &cap->enc[i].bits,
 		    &cap->enc[i].sig,
-		    &cap->enc[i].le);		
+		    &cap->enc[i].le);
 		cap->enc[i].bps = SIO_BPS(cap->enc[0].bits);
 		cap->enc[i].msb = 1;
 	}
@@ -780,7 +796,7 @@ sio_alsa_setpar(struct sio_hdl *sh, struct sio_par *par)
 	    ofmt, orate, (unsigned int)oround, operiods);
 	DPRINTFN(2, "ifmt = %u, irate = %u, iround = %u, iperiods = %u\n",
 	    ifmt, irate, (unsigned int)iround, iperiods);
-	
+
 	if (ifmt != ofmt) {
 		DPRINTF("play and rec formats differ\n");
 		hdl->sio.eof = 1;
@@ -1106,7 +1122,7 @@ sio_alsa_revents(struct sio_hdl *sh, struct pollfd *pfd)
 
 	if (hdl->sio.eof)
 		return POLLHUP;
-	
+
 	for (i = 0; i < hdl->onfds + hdl->infds; i++) {
 		DPRINTFN(4, "sio_alsa_revents: pfds[%d].revents = %x\n",
 		    i, pfd[i].revents);
