@@ -34,6 +34,11 @@
 #include "sio_priv.h"
 #include "bsd-compat.h"
 
+#define DEVPATH_PREFIX	"/dev/audio"
+#define DEVPATH_MAX 	(1 +		\
+	sizeof(DEVPATH_PREFIX) - 1 +	\
+	sizeof(int) * 3)
+
 struct sio_sun_hdl {
 	struct sio_hdl sio;
 	int fd;
@@ -325,40 +330,57 @@ sio_sun_getcap(struct sio_hdl *sh, struct sio_cap *cap)
 #undef NRATES
 }
 
-struct sio_hdl *
-_sio_sun_open(const char *str, unsigned int mode, int nbio)
+static int
+sio_sun_getfd(const char *str, unsigned int mode, int nbio)
 {
-	int fd, flags, fullduplex;
-	struct audio_info aui;
-	struct sio_sun_hdl *hdl;
-	struct sio_par par;
-	char path[PATH_MAX];
+	const char *p;
+	char path[DEVPATH_MAX];
+	unsigned int devnum;
+	int fd, flags;
 
-	switch (*str) {
+	p = _sndio_parsetype(str, "rsnd");
+	if (p == NULL) {
+		DPRINTF("sio_sun_getfd: %s: \"rsnd\" expected\n", str);
+		return -1;
+	}
+	switch (*p) {
 	case '/':
-		str++;
+		p++;
 		break;
 	default:
-		DPRINTF("_sio_sun_open: %s: '/<devnum>' expected\n", str);
-		return NULL;
+		DPRINTF("sio_sun_getfd: %s: '/' expected\n", str);
+		return -1;
 	}
-	hdl = malloc(sizeof(struct sio_sun_hdl));
-	if (hdl == NULL)
-		return NULL;
-	_sio_create(&hdl->sio, &sio_sun_ops, mode, nbio);
-
-	snprintf(path, sizeof(path), "/dev/audio%s", str);
+	p = _sndio_parsenum(p, &devnum, 255);
+	if (p == NULL || *p != '\0') {
+		DPRINTF("sio_sun_getfd: %s: number expected after '/'\n", str);
+		return -1;
+	}
+	snprintf(path, sizeof(path), DEVPATH_PREFIX "%u", devnum);
 	if (mode == (SIO_PLAY | SIO_REC))
 		flags = O_RDWR;
 	else
 		flags = (mode & SIO_PLAY) ? O_WRONLY : O_RDONLY;
-
 	while ((fd = open(path, flags | O_NONBLOCK | O_CLOEXEC)) < 0) {
 		if (errno == EINTR)
 			continue;
 		DPERROR(path);
-		goto bad_free;
+		return -1;
 	}
+	return fd;
+}
+
+static struct sio_hdl *
+sio_sun_fdopen(int fd, unsigned int mode, int nbio)
+{
+	struct audio_info aui;
+	struct sio_sun_hdl *hdl;
+	struct sio_par par;
+
+	hdl = malloc(sizeof(struct sio_sun_hdl));
+	if (hdl == NULL)
+		return NULL;
+	_sio_create(&hdl->sio, &sio_sun_ops, mode, nbio);
 
 	/*
 	 * pause the device
@@ -370,18 +392,7 @@ _sio_sun_open(const char *str, unsigned int mode, int nbio)
 		aui.record.pause = 1;
 	if (ioctl(fd, AUDIO_SETINFO, &aui) < 0) {
 		DPERROR("sio_open_sun: setinfo");
-		goto bad_close;
-	}
-	/*
-	 * If both play and record are requested then
-	 * set full duplex mode.
-	 */
-	if (mode == (SIO_PLAY | SIO_REC)) {
-		fullduplex = 1;
-		if (ioctl(fd, AUDIO_SETFD, &fullduplex) < 0) {
-			DPRINTF("sio_open_sun: %s: can't set full-duplex\n", path);
-			goto bad_close;
-		}
+		goto bad_free;
 	}
 	hdl->fd = fd;
 
@@ -399,16 +410,30 @@ _sio_sun_open(const char *str, unsigned int mode, int nbio)
 	par.bits = 16;
 	par.appbufsz = 1200;
 	if (!sio_setpar(&hdl->sio, &par))
-		goto bad_close;
+		goto bad_free;
 	return (struct sio_hdl *)hdl;
- bad_close:
-	while (close(fd) < 0 && errno == EINTR)
-		; /* retry */
  bad_free:
 	free(hdl);
 	return NULL;
 }
 
+struct sio_hdl *
+_sio_sun_open(const char *str, unsigned int mode, int nbio)
+{
+	struct sio_hdl *hdl;
+	int fd;
+
+	fd = sio_sun_getfd(str, mode, nbio);
+	if (fd < 0)
+		return NULL;
+	hdl = sio_sun_fdopen(fd, mode, nbio);
+	if (hdl != NULL)
+		return hdl;
+	while (close(fd) < 0 && errno == EINTR)
+		; /* retry */
+	return NULL;
+}
+
 static void
 sio_sun_close(struct sio_hdl *sh)
 {
@@ -535,7 +560,8 @@ sio_sun_setpar(struct sio_hdl *sh, struct sio_par *par)
 		}
 		DPRINTFN(2, "sio_sun_setpar: %i: trying pars = %u/%u/%u\n",
 		    i, rate, prec, enc);
-		if (ioctl(hdl->fd, AUDIO_SETINFO, &aui) < 0 && errno != EINVAL) {
+		if (ioctl(hdl->fd, AUDIO_SETINFO, &aui) < 0 &&
+		    errno != EINVAL) {
 			DPERROR("sio_sun_setpar: setinfo(pars)");
 			hdl->sio.eof = 1;
 			return 0;
@@ -556,7 +582,7 @@ sio_sun_setpar(struct sio_hdl *sh, struct sio_par *par)
 		case AUDIO_ENCODING_ULINEAR:
 			break;
 		default:
-			DPRINTF("sio_sun_setpar: couldn't set linear encoding\n");
+			DPRINTF("sio_sun_setpar: couldn't find encoding\n");
 			hdl->sio.eof = 1;
 			return 0;
 		}
@@ -647,7 +673,7 @@ sio_sun_setpar(struct sio_hdl *sh, struct sio_par *par)
 		}
 		infr = aui.record.block_size / ibpf;
 		onfr = aui.play.block_size / obpf;
-		DPRINTFN(2, "sio_sun_setpar: %i: trying round = %u -> (%u, %u)\n",
+		DPRINTFN(2, "sio_sun_setpar: %i: round = %u -> (%u, %u)\n",
 		    i, round, infr, onfr);
 
 		/*
@@ -777,7 +803,7 @@ sio_sun_write(struct sio_hdl *sh, const void *buf, size_t len)
 			DPERROR("sio_sun_write: write");
 			hdl->sio.eof = 1;
 		}
- 		return 0;
+		return 0;
 	}
 	if (hdl->filling) {
 		if (!sio_sun_autostart(hdl))
@@ -822,7 +848,7 @@ sio_sun_revents(struct sio_hdl *sh, struct pollfd *pfd)
 		doerr = (ap.play_xrun - hdl->oerr) / hdl->obpf;
 		hdl->obytes = ap.play_pos;
 		hdl->oerr = ap.play_xrun;
-		hdl->odelta += delta;	
+		hdl->odelta += delta;
 		if (!(hdl->sio.mode & SIO_REC)) {
 			hdl->idelta += delta;
 			dierr = doerr;
