@@ -162,7 +162,7 @@ dev_sio_open(struct dev *d)
 		log_putu(par.pchan);
 		log_puts(": unsupported number of play channels\n");
 		goto bad_close;
-	}	
+	}
 	if ((mode & SIO_REC) && par.rchan > NCHAN_MAX) {
 		log_puts(d->path);
 		log_puts(": ");
@@ -230,7 +230,7 @@ dev_sio_close(struct dev *d)
 #endif
 	timo_del(&d->sio.watchdog);
 	file_del(d->sio.file);
-	sio_close(d->sio.hdl);	
+	sio_close(d->sio.hdl);
 }
 
 void
@@ -293,7 +293,7 @@ dev_sio_pollfd(void *arg, struct pollfd *pfd)
 {
 	struct dev *d = arg;
 	int events;
-	
+
 	events = (d->sio.cstate == DEV_SIO_READ) ? POLLIN : POLLOUT;
 	return sio_pollfd(d->sio.hdl, pfd, events);
 }
@@ -353,7 +353,8 @@ dev_sio_run(void *arg)
 			n = sio_read(d->sio.hdl, data, d->sio.todo);
 			d->sio.todo -= n;
 #ifdef DEBUG
-			if (n == 0 && data == base && !sio_eof(d->sio.hdl)) {
+			if (log_level >= 3 &&
+			    n == 0 && data == base && !sio_eof(d->sio.hdl)) {
 				dev_log(d);
 				log_puts(": read blocked at cycle start\n");
 			}
@@ -436,7 +437,8 @@ dev_sio_run(void *arg)
 			n = sio_write(d->sio.hdl, data, d->sio.todo);
 			d->sio.todo -= n;
 #ifdef DEBUG
-			if (n == 0 && data == base && !sio_eof(d->sio.hdl)) {
+			if (log_level >= 3 &&
+			    n == 0 && data == base && !sio_eof(d->sio.hdl)) {
 				dev_log(d);
 				log_puts(": write blocked at cycle start\n");
 			}
