@@ -153,6 +153,7 @@ sock_close(struct sock *f)
 	}
 	file_del(f->file);
 	close(f->fd);
+	file_slowaccept = 0;
 	xfree(f);
 }
 
@@ -337,7 +338,7 @@ sock_fdwrite(struct sock *f, void *data, int count)
 			}
 			sock_close(f);
 		} else {
-#ifdef DEBUG			
+#ifdef DEBUG
 			if (log_level >= 4) {
 				sock_log(f);
 				log_puts(": write blocked\n");
@@ -378,7 +379,7 @@ sock_fdread(struct sock *f, void *data, int count)
 			}
 			sock_close(f);
 		} else {
-#ifdef DEBUG			
+#ifdef DEBUG
 			if (log_level >= 4) {
 				sock_log(f);
 				log_puts(": read blocked\n");
@@ -1096,7 +1097,7 @@ sock_execmsg(struct sock *f)
 				f->ralign = s->round * s->mix.bpf;
 			}
 		}
-		slot_stop(s);		
+		slot_stop(s);
 		break;
 	case AMSG_SETPAR:
 #ifdef DEBUG
@@ -1284,7 +1285,7 @@ sock_execmsg(struct sock *f)
 int
 sock_buildmsg(struct sock *f)
 {
-	unsigned int size;	
+	unsigned int size;
 
 	/*
 	 * If pos changed (or initial tick), build a MOVE message.
@@ -1314,7 +1315,7 @@ sock_buildmsg(struct sock *f)
 
 	if (f->fillpending > 0) {
 		AMSG_INIT(&f->wmsg);
-		f->wmsg.cmd = htonl(AMSG_FLOWCTL);	       
+		f->wmsg.cmd = htonl(AMSG_FLOWCTL);
 		f->wmsg.u.ts.delta = htonl(f->fillpending);
 		size = f->fillpending;
 		if (f->slot)
@@ -1358,7 +1359,7 @@ sock_buildmsg(struct sock *f)
 	}
 
 	if (f->midi != NULL && f->midi->obuf.used > 0) {
-		size = f->midi->obuf.used;		
+		size = f->midi->obuf.used;
 		if (size > AMSG_DATAMAX)
 			size = AMSG_DATAMAX;
 		AMSG_INIT(&f->wmsg);
